@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2018 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 package main
 
 import (
@@ -15,7 +19,7 @@ import (
 	"strings"
 	"time"
 
-	"github.com/godbus/dbus"
+	"github.com/godbus/dbus/v5"
 )
 
 const (
@@ -131,10 +135,10 @@ func handleAction(m *upgrader.Upgrader, c *config.Config) {
 			logger.Error("must special version")
 			os.Exit(FAILED_VERSION_EXISTS)
 		}
-		err := m.Snapshot(*_version)
+		exCode, err := m.EnableBoot(*_version)
 		if err != nil {
 			logger.Errorf("snapshot %q: %v", *_version, err)
-			os.Exit(int(FAILED_VERSION_EXISTS))
+			os.Exit(int(exCode))
 		}
 	case _ACTION_BOOTLIST:
 		// close log
