@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2018 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 package upgrader
 
 import (
@@ -29,7 +33,7 @@ import (
 	"strings"
 	"time"
 
-	"github.com/godbus/dbus"
+	"github.com/godbus/dbus/v5"
 )
 
 var msgSuccessRollBack = util.Tr("Your system is successfully rolled back to %s.")
@@ -375,7 +379,7 @@ func (c *Upgrader) UpdateGrub() (stateType, error) {
 
 func (c *Upgrader) EnableBoot(version string) (stateType, error) {
 	exitCode := _STATE_TY_SUCCESS
-	err := c.repoSnapShotSubDir(c.conf.RepoList[0], "/boot", version)
+	err := c.Snapshot(version)
 	if err != nil {
 		exitCode = _STATE_TY_FAILED_NO_REPO
 		return exitCode, err
@@ -763,15 +767,8 @@ func (c *Upgrader) repoSnapShot(repoConf *config.RepoConfig, version string) err
 	return handler.Snapshot(version, dataDir)
 }
 
-func (c *Upgrader) repoSnapShotSubDir(repoConf *config.RepoConfig, subDir, version string) error {
-	handler := c.repoSet[repoConf.Repo]
-	dataDir := filepath.Join(c.rootMP, repoConf.SnapshotDir, version)
-	_ = os.RemoveAll(dataDir)
-	return handler.SnapshotSub(version, subDir, dataDir)
-}
-
 func (c *Upgrader) enableSnapshotBoot(snapDir, version string) error {
-	bootDir := snapDir
+	bootDir := filepath.Join(snapDir, "boot")
 	fiList, err := ioutil.ReadDir(bootDir)
 	if err != nil {
 		return err
